@@ -348,7 +348,8 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
         && furnitureResourcesRemoteAbsoluteUrlBase == null 
         && furnitureResourcesRemoteRelativeUrlBase == null;
     DateFormat creationDateFormat = new SimpleDateFormat("yyyy-MM-dd");
-    Set<String> existingEntryNames = new HashSet<String>();
+    // Store existing entries in lower case to be able to compare their names ignoring case
+    Set<String> existingEntryNamesLowerCase = new HashSet<String>();
     BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(output, "ISO-8859-1"));
     final String CATALOG_FILE_HEADER = "#\n# " 
         + DefaultFurnitureCatalog.PLUGIN_FURNITURE_CATALOG_FAMILY + ".properties %tc\n" 
@@ -401,47 +402,60 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
       }
       // Replace # and & symbols in file names to avoid wrongly encoded URLs
       contentBaseName = contentBaseName.replace('%', '_').replace('#', '_');
-      String iconContentEntryName = getContentEntry(piece.getIcon(), contentBaseName + ".png", 
-          keepURLContentUnchanged, existingEntryNames);
-      writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.ICON, i, 
-          getContentProperty(piece.getIcon(), iconContentEntryName, offlineFurnitureLibrary, 
-              furnitureResourcesRemoteAbsoluteUrlBase, furnitureResourcesRemoteRelativeUrlBase));
-      if (iconContentEntryName != null) {
-        contentEntries.put(piece.getIcon(), iconContentEntryName);
-      }
-      if (piece.getPlanIcon() != null) {
-        String planIconContentEntryName = getContentEntry(piece.getPlanIcon(), contentBaseName + "PlanIcon.png", 
-            keepURLContentUnchanged, existingEntryNames);
-        writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.PLAN_ICON, i, 
-            getContentProperty(piece.getPlanIcon(), planIconContentEntryName, offlineFurnitureLibrary,
-                furnitureResourcesRemoteAbsoluteUrlBase, furnitureResourcesRemoteRelativeUrlBase));
-        if (planIconContentEntryName != null) {
-          contentEntries.put(piece.getPlanIcon(), planIconContentEntryName);
+      Content pieceIcon = piece.getIcon();
+      String iconContentEntryName = contentEntries.get(pieceIcon);
+      // If piece icon content not referenced yet among saved content 
+      if (iconContentEntryName == null) {
+        iconContentEntryName = getContentEntry(pieceIcon, contentBaseName + ".png", 
+            keepURLContentUnchanged, existingEntryNamesLowerCase);
+        if (iconContentEntryName != null) {
+          contentEntries.put(pieceIcon, iconContentEntryName);
         }
       }
+      writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.ICON, i, 
+          getContentProperty(pieceIcon, iconContentEntryName, offlineFurnitureLibrary, 
+              furnitureResourcesRemoteAbsoluteUrlBase, furnitureResourcesRemoteRelativeUrlBase));
+      Content piecePlanIcon = piece.getPlanIcon();
+      if (piecePlanIcon != null) {
+        String planIconContentEntryName = contentEntries.get(piecePlanIcon);
+        // If plan icon content not referenced yet among saved content
+        if (planIconContentEntryName == null) {
+          planIconContentEntryName = getContentEntry(piecePlanIcon, contentBaseName + "PlanIcon.png", 
+              keepURLContentUnchanged, existingEntryNamesLowerCase);
+          if (planIconContentEntryName != null) {
+            contentEntries.put(piecePlanIcon, planIconContentEntryName);
+          }
+        }
+        writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.PLAN_ICON, i, 
+            getContentProperty(piecePlanIcon, planIconContentEntryName, offlineFurnitureLibrary,
+                furnitureResourcesRemoteAbsoluteUrlBase, furnitureResourcesRemoteRelativeUrlBase));
+      }
       boolean multipart = pieceModel instanceof ResourceURLContent
               && ((ResourceURLContent)pieceModel).isMultiPartResource()
           || !(pieceModel instanceof ResourceURLContent)
               && pieceModel instanceof URLContent
               && ((URLContent)pieceModel).isJAREntry();
-      String modelContentEntryName;
-      if (multipart) {
-        String jarEntryName = ((URLContent)pieceModel).getJAREntryName();
-        modelContentEntryName = getContentEntry(pieceModel,
-            pieceModel instanceof TemporaryURLContent
-                ? contentBaseName + "/" + jarEntryName 
-                : contentBaseName + "/" + jarEntryName.substring(jarEntryName.lastIndexOf('/') + 1),  
-            keepURLContentUnchanged, existingEntryNames);
-      } else {
-        modelContentEntryName = getContentEntry(pieceModel, 
-            contentBaseName + ".obj", keepURLContentUnchanged, existingEntryNames);
+      String modelContentEntryName = contentEntries.get(pieceModel);
+      // If piece model content not referenced yet among saved content
+      if (modelContentEntryName == null) {
+        if (multipart) {
+          String jarEntryName = ((URLContent)pieceModel).getJAREntryName();
+          modelContentEntryName = getContentEntry(pieceModel,
+              pieceModel instanceof TemporaryURLContent
+                  ? contentBaseName + "/" + jarEntryName 
+                  : contentBaseName + "/" + jarEntryName.substring(jarEntryName.lastIndexOf('/') + 1),  
+              keepURLContentUnchanged, existingEntryNamesLowerCase);
+        } else {
+          modelContentEntryName = getContentEntry(pieceModel, 
+              contentBaseName + ".obj", keepURLContentUnchanged, existingEntryNamesLowerCase);
+        }
+        if (modelContentEntryName != null) {
+          contentEntries.put(pieceModel, modelContentEntryName);
+        }
       }
       writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.MODEL, i, 
           getContentProperty(pieceModel, modelContentEntryName, offlineFurnitureLibrary, 
               furnitureResourcesRemoteAbsoluteUrlBase, furnitureResourcesRemoteRelativeUrlBase));
-      if (modelContentEntryName != null) {
-        contentEntries.put(pieceModel, modelContentEntryName);
-      }
       if (multipart) {
         writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.MULTI_PART_MODEL, i, "true");
       }
@@ -623,12 +637,12 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
   private String getContentEntry(Content content,
                                  String entryName,
                                  boolean keepURLContentUnchanged, 
-                                 Set<String> existingEntryNames) throws IOException {
+                                 Set<String> existingEntryNamesLowerCase) throws IOException {
     if (content instanceof TemporaryURLContent
         || content instanceof ResourceURLContent) {
       int slashIndex = entryName.indexOf('/'); 
       if (slashIndex == -1) {
-        if (existingEntryNames.contains(entryName)) {
+        if (existingEntryNamesLowerCase.contains(entryName.toLowerCase())) {
           // Search an unexisting entry name
           int i = 2;
           String defaultEntryName = entryName;
@@ -636,16 +650,18 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
             int dotIndex = defaultEntryName.lastIndexOf('.');
             entryName = defaultEntryName.substring(0, dotIndex) 
                 + i++ + defaultEntryName.substring(dotIndex);  
-          } while (existingEntryNames.contains(entryName));
+          } while (existingEntryNamesLowerCase.contains(entryName.toLowerCase()));
         }
       } else {
         String entryDirectory = entryName.substring(0, slashIndex + 1);
         int i = 2;
         while (true) {
           boolean entryDirectoryExists = false;
+          String entryDirectoryLowerCase = entryDirectory.toLowerCase();
           // Search an unexisting entry directory
-          for (String existingEntryName : existingEntryNames) {
-            if (existingEntryName.startsWith(entryDirectory)) {
+          for (String existingEntryNameLowerCase : existingEntryNamesLowerCase) {
+            // If existingEntryName starts with entryDirectory ignoring case
+            if (existingEntryNameLowerCase.startsWith(entryDirectoryLowerCase)) {
               entryDirectoryExists = true;
               break;
             }
@@ -658,7 +674,7 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
           }
         }
       }
-      existingEntryNames.add(entryName);
+      existingEntryNamesLowerCase.add(entryName.toLowerCase());
       return entryName;
     } else if (content instanceof URLContent) {
       if (keepURLContentUnchanged) {
@@ -680,7 +696,7 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
           String file = urlContent.getURL().getFile();
           entryName = file.substring(file.lastIndexOf('/') + 1);
         }
-        existingEntryNames.add(entryName);
+        existingEntryNamesLowerCase.add(entryName.toLowerCase());
         return entryName;
       }
     } else {
